Module: Mushin::Logger::Colors

Defined in:
lib/mushin/logger.rb

Overview

Colorizes the output of the standard library logger, depending on the logger level: To adjust the colors, look at Logger::Colors::SCHEMA and Logger::Colors::constants

LEVELS

UNKNOWN: An unknown message that should always be logged. FATAL: An unhandleable error that results in a program crash. ERROR: A handleable error condition. WARN: A warning. INFO: Generic (useful) information about system operation. DEBUG: Low-level information for developers. class Logger < Logger

Constant Summary collapse

NOTHING =
'0;0'
BLACK =
'0;30'
RED =
'0;31'
GREEN =
'0;32'
BROWN =
'0;33'
BLUE =
'0;34'
PURPLE =
'0;35'
CYAN =
'0;36'
LIGHT_GRAY =
'0;37'
DARK_GRAY =
'1;30'
LIGHT_RED =
'1;31'
LIGHT_GREEN =
'1;32'
YELLOW =
'1;33'
LIGHT_BLUE =
'1;34'
LIGHT_PURPLE =
'1;35'
LIGHT_CYAN =
'1;36'
WHITE =
'1;37'
SCHEMA =
{
  STDOUT => %w[nothing green brown red purple cyan],
  #STDERR => %w[nothing green yellow light_red light_purple light_cyan],
  STDERR => %w[dark_gray nothing yellow light_red light_purple light_cyan],
}